@@ -1,24 +1,40 @@
 # -*- coding: utf-8 -*-
-# $Id: browser.py 237921 2011-04-20 16:04:48Z glenfant $
+# $Id: browser.py 246084 2011-11-01 22:45:18Z glenfant $
 """Views for the control panel"""
+
 from urllib import quote_plus
+from zope.interface import alsoProvides
 from zope.schema import getFieldsInOrder
+from ZTUtils import make_query
 from Products.Five.browser import BrowserView
-from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
+from aws.zope2zcmldoc.interfaces import IControlPanelBrowserRequest
+from aws.zope2zcmldoc import awsZope2zcmldocMF as _
 
 NO_NAMESPACE = '(No namespace)'
 
+
 class ZMIView(BrowserView):
     """View class for our control panel
     """
 
+    def __init__(self, *args, **kwargs):
+        super(ZMIView, self).__init__(*args, **kwargs)
+        alsoProvides(self.request, IControlPanelBrowserRequest)
+
+    def to_english_link(self):
+        """The "In english" link
+        """
+        form = self.request.form.copy()
+        form['forced_en'] = True
+        return self.request.URL + '?' + make_query(**form)
+
     def namespaces(self):
         """List of mappings with keys :
         - 'namespace_url'
         - 'view_url'
         """
         out = []
-        namespaces= self.context.getNamespaces().keys()
+        namespaces = self.context.getNamespaces().keys()
         namespaces.sort()
         for namespace in namespaces:
             if namespace == '':
@@ -35,30 +51,26 @@ class ZMIView(BrowserView):
         """
         return self.request.form.get('ns')
 
-
     def this_namespace_view_url(self):
         return '@@view_namespace?ns=%s' % quote_plus(self.this_namespace())
 
-
     def this_directive(self):
         """Name of actually focused directive
         """
         return self.request.form.get('directive')
 
-
     def this_directive_view_url(self):
         return '@@view_directive?ns=%s&directive=%s' % (
                quote_plus(self.this_namespace()), self.this_directive())
 
-
     def this_subdirective(self):
         """Name of actually focused directive
         """
         return self.request.form.get('subdir')
 
-
     def list_directives(self):
-        """Enumerates sorted directives for this_namespace as mappings with keys :
+        """Enumerates sorted directives for this_namespace as mappings with
+        keys:
         - 'name'
         - 'view_url'
         """
@@ -77,7 +89,6 @@ class ZMIView(BrowserView):
             out.append(features)
         return out
 
-
     def directive_infos(self):
         """Provide ZPT friendly data to display a directive documentation
         """
@@ -88,7 +99,6 @@ class ZMIView(BrowserView):
         schema, handler, zcml_source = self.context.getNamespaces()[this_namespace][this_directive]
         return DirectiveInfos(schema, handler, zcml_source)
 
-
     def list_subdirectives(self):
         """Provide links to potential subdirectives as mappings with keys:
         - 'name'
@@ -110,7 +120,6 @@ class ZMIView(BrowserView):
             out.append(features)
         return out
 
-
     def subdirective_infos(self):
         """Provide ZPT friendly data to display a directive documentation
         """
@@ -118,7 +127,6 @@ class ZMIView(BrowserView):
         if this_namespace == NO_NAMESPACE:
             this_namespace = ''
         this_directive = self.this_directive()
-        this_subdirective = self.this_subdirective()
         key = (this_namespace, this_directive)
         subdirs = self.context.getSubdirs().get(key, [])
         for namespace, name, schema, handler, zcml_source in subdirs:
@@ -138,11 +146,11 @@ class DirectiveInfos(object):
 
     def summary(self):
         """Text summary of the directive
-        FIXME: may be in rst
+        FIXME: may be in rst, but how to detect it
         """
         summary = self._schema.getDoc()
         if summary.strip() == '':
-            summary = "(not available)"
+            summary = _(u'not_available', default=u"(Not available)")
         return summary
 
     def attributes(self):
